@@ -12,6 +12,7 @@
 #include <QRegExp>
 #include <QPixmap>
 #include <QImage>
+#include "backgrounds.h"
 
 namespace Ui {
     class MainWindow;
@@ -47,8 +48,12 @@ private:
     QString f6;
     QString f7;
     QString f8;
+    backgrounds* newWin;
+    bool openManWin;
+    bool openNewWin;
 
 private slots:
+    void on_pushButton_2_clicked();
     void on_horizontalSlider_4_valueChanged(int value);
     void on_Opacity_editingFinished();
     void on_font8_editingFinished();
