@@ -123,6 +123,11 @@
         <source>Widget opacity %</source>
         <translation>Widgettien näkyvyys %</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Set backgrounds</source>
+        <translation>Muuta taustakuvia</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
         <source>App shortcut size</source>
